get_idx_in_group_output

Function get_idx_in_group_output 

fn get_idx_in_group_output(output_frameno_in_gop: u64) -> u64
Get the index of an output frame in its re-ordering group given the output frame number of the frame in the current keyframe gop. When re-ordering is disabled, this always returns 0.