fn get_order_hint(output_frameno_in_gop: u64, idx_in_group_output: u64) -> u32Expand description
Get the order-hint of an output frame given the output frame number of the frame in the current keyframe gop and the index of that output frame in its re-ordering gorup.