pub struct FrameState<T: Pixel> {
pub input: Arc<Frame<T>>,
pub input_hres: Arc<Plane<T>>,
pub input_qres: Arc<Plane<T>>,
pub frame_me_stats: Arc<RwLock<[FrameMEStats; 8]>>,
}Fields
input: Arc<Frame<T>>input_hres: Arc<Plane<T>>input_qres: Arc<Plane<T>>frame_me_stats: Arc<RwLock<[FrameMEStats; 8]>>Implementations
Sourceimpl<T: Pixel> FrameState<T>
impl<T: Pixel> FrameState<T>
Sourcepub fn new_with_frame_and_me_stats_and_rec(
frame: Arc<Frame<T>>,
me_stats: Arc<RwLock<[FrameMEStats; 8]>>,
) -> Self
pub fn new_with_frame_and_me_stats_and_rec( frame: Arc<Frame<T>>, me_stats: Arc<RwLock<[FrameMEStats; 8]>>, ) -> Self
Similar to [FrameState::new_with_frame], but takes an me_stats
and rec to enable reusing the same underlying allocations to create
a FrameState
This function primarily exists for [estimate_inter_costs], and so
it does not create hres or qres versions of frame as downscaling is
somewhat expensive and are not needed for [estimate_inter_costs].